@@ -1,6 +1,6 @@
 #' Pipe operator
 #'
-#' See \code{\link[magrittr]{\%>\%}} for more details.
+#' See \code{\link[magrittr]{magrittr::`%>%`()}} for more details.
 #'
 #' @name %>%
 #' @rdname pipe
@@ -29,5 +29,5 @@ NULL
 not_in <- function(x,y)!('%in%'(x,y))
 
 # Get rid of NOTES
-globalVariables(c(".", ".data", "long_str"))
+globalVariables(c(".", ".data", "long_str", "lyric", "second_sentence"))
 
